{% extends "lotus/base.html" %}
{% load i18n %}

{% block header-title %}{% trans "Tags" %} | {{ django_blog_plus_site_name|default:"Blog" }}{% endblock header-title %}

{% block lotus_content %}
<div class="lotus-extras-blog-container">
    <div class="lotus-extras-page-header">
        <h1 class="lotus-extras-page-title">{% trans "Tags" %}</h1>
        <p class="lotus-extras-page-description">{% trans "Browse articles by tag" %}</p>
    </div>

    {% if tag_list %}
    <div class="lotus-extras-tags-cloud">
        {% for tag in tag_list %}
        <a href="{{ tag.get_absolute_url }}" class="lotus-extras-tag">{{ tag.name }}</a>
        {% endfor %}
    </div>
    {% else %}
    <p>{% trans "No tags found." %}</p>
    {% endif %}
</div>
{% endblock lotus_content %}
