from django.apps import AppConfig


class DjangoBlogPlusConfig(AppConfig):
    """App configuration for Django Blog Plus."""
    
    name = "django_blog_plus"
    verbose_name = "Django Blog Plus"
    default_auto_field = "django.db.models.BigAutoField"
    
    def ready(self):
        """Called when the app is ready."""
        # Import signal handlers if needed
        pass
