# Generated by Django 5.2.1 on 2026-02-11 15:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_blog_plus', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='articlecoverstyle',
            name='background_color',
            field=models.CharField(choices=[('#f8f9fa', 'Light Gray (Default)'), ('#ffffff', 'White'), ('#000000', 'Black'), ('#1a1a2e', 'Dark Navy'), ('#16213e', 'Deep Blue'), ('#0f3460', 'Ocean Blue'), ('#5DBEA3', 'Teal Green'), ('#30BE93', 'Green'), ('#e8f5e9', 'Light Green'), ('#fff3e0', 'Light Orange'), ('#fce4ec', 'Light Pink'), ('#e3f2fd', 'Light Blue'), ('#f3e5f5', 'Light Purple'), ('#fffde7', 'Light Yellow'), ('#263238', 'Charcoal'), ('#37474f', 'Blue Gray')], default='#f8f9fa', help_text='Background color for the article cover image container', max_length=7),
        ),
    ]
