{% extends django_blog_plus_base_template|default:"base.html" %}
{% load static %}

{% block header-resource-extra %}
    {{ block.super }}
    <link rel="canonical" href="{{ request.scheme }}://{{ canonical_host|default:request.get_host }}{{ request.path }}">
    <link rel="alternate" type="application/rss+xml" title="{{ django_blog_plus_site_name|default:'Blog' }} RSS Feed" href="{% url 'django_blog_plus:feed-rss' %}">
    <link rel="alternate" type="application/atom+xml" title="{{ django_blog_plus_site_name|default:'Blog' }} Atom Feed" href="{% url 'django_blog_plus:feed-atom' %}">
{% endblock header-resource-extra %}

{% block content %}
<div id="lotus-content">
    {% block lotus_content %}{% endblock lotus_content %}
</div>
{% endblock content %}
