{% load static %}

<meta charset="utf-8" />
<meta content="width=device-width, initial-scale=1" name="viewport" />
<link href="{% static 'images/favicon.png' %}" rel="shortcut icon" type="image/x-icon" />

{#-- JSON-LD Organization Schema (Global) --#}
<script type="application/ld+json">
{
  "@context": "https://schema.org",
  "@type": "Organization",
  "name": "Django Blog Plus",
  "url": "https://pypi.org/project/django-blog-plus/",
  "description": "Enhanced features for django-blog-lotus: CTAs, cover styling, webhooks, view tracking, and more.",
  "contactPoint": {
    "@type": "ContactPoint",
    "email": "support@visiansystems.com",
    "contactType": "customer service",
    "availableLanguage": "English"
  },
  "address": {
    "@type": "PostalAddress",
    "streetAddress": "Stapeley House, London Rd, Stapeley",
    "addressLocality": "Nantwich",
    "postalCode": "CW5 7JW",
    "addressCountry": "GB"
  }
}
</script>

{#-- Preload Critical Assets for LCP --#}
<link rel="preload" href="{% static 'lotus_extras/css/design-tokens.css' %}" as="style" />

{#-- Design System - Core --#}
<link href="{% static 'lotus_extras/css/design-tokens.css' %}" rel="stylesheet" type="text/css" />
<link href="{% static 'lotus_extras/css/components.css' %}" rel="stylesheet" type="text/css" />
{#-- Legacy styles (gradual deprecation) --#}
<link href="{% static 'lotus_extras/css/normalize.css' %}" rel="stylesheet" type="text/css" />
<link href="{% static 'lotus_extras/css/webflow.css' %}" rel="stylesheet" type="text/css" />
<link href="{% static 'lotus_extras/css/blog.webflow.css' %}" rel="stylesheet" type="text/css" />
<link href="{% static 'lotus_extras/css/blog-improvements.css' %}" rel="stylesheet" type="text/css" />
<link href="{% static 'lotus_extras/css/hero-modern.css' %}" rel="stylesheet" type="text/css" />
{#-- Premium Polish - Load last to override all other styles --#}
<link href="{% static 'lotus_extras/css/premium-polish.css' %}?v=5" rel="stylesheet" type="text/css" />
<style nonce="{{ request.csp_nonce }}">
    /* Nav underline closer to text */
    .nav-link::after {
        bottom: 4px !important;
    }
</style>
<link href="https://fonts.googleapis.com" rel="preconnect" />
<link href="https://fonts.gstatic.com" rel="preconnect" crossorigin="anonymous" />
<link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap" rel="stylesheet" />
<link href="https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.8/css/intlTelInput.css" rel="stylesheet" />
<link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.6.0/css/all.min.css" rel="stylesheet">

{#-- Start cookie --#}
<script nonce="{{ request.csp_nonce }}" type="text/javascript" src="https://app.getterms.io/cookie-consent/embed/84d5034a-16de-42bc-891e-b345a38ad608/en-au"></script>

<script nonce="{{ request.csp_nonce }}" src="https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.8/js/intlTelInput.min.js"></script>
<script nonce="{{ request.csp_nonce }}" src="https://ajax.googleapis.com/ajax/libs/webfont/1.6.26/webfont.js"></script>

{# Load jQuery first #}
<script nonce="{{ request.csp_nonce }}" src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
{# Then load Popper.js #}
<script nonce="{{ request.csp_nonce }}" src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.9.3/dist/umd/popper.min.js"></script>
{# Lastly, load Bootstrap JS #}
<script nonce="{{ request.csp_nonce }}" src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

<script nonce="{{ request.csp_nonce }}" src="https://kit.fontawesome.com/25e701a518.js" crossorigin="anonymous"></script>
<style>
  body {
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
  }
</style>
